# streamlit-tutorial
[Doc](https://docs.streamlit.io/)

# Usage
1. install:
  ```
  pip install -r requirements.txt
  ```
2. run:
  ```
  streamlit run xxx.py
  ```

An example:
```
streamlit run multi-page_apps/home.py
```

# Deployment
After you’ve built a Streamlit app, it's time to share it! To show it off to the world you can use Streamlit Cloud to deploy, manage, and share your app for free.

It works in 3 simple steps:

Put your app in a public GitHub repo (and make sure it has a requirements.txt!)

Sign into share.streamlit.io

Click 'Deploy an app' and then paste in your GitHub URL

That's it! 🎈 You now have a publicly deployed app that you can share with the world. Click to learn more about how to use Streamlit Cloud.
